@@ -1,7 +1,6 @@
 from typing import List
 from typing import Optional
 
-from pydantic.class_validators import root_validator
 from pydantic.fields import Field
 
 from .content import TikTokContentModel
@@ -19,10 +18,9 @@ class TikTokUserModel(BaseModelORM):
     likes_count: Optional[int] = Field(None, alias="total_favorited")
     verified: Optional[int] = Field(0, alias="verification_type")
 
-    avatar_168x168: TikTokContentModel
-    avatar_300x300: TikTokContentModel
-    avatar_larger: TikTokContentModel
-    avatar_medium: TikTokContentModel
-    avatar_thumb: TikTokContentModel
-    cover_url: Optional[List[TikTokContentModel]]
-    avatar_medium: TikTokContentModel
+    avatar_168x168: Optional[TikTokContentModel]
+    avatar_300x300: Optional[TikTokContentModel]
+    avatar_larger: Optional[TikTokContentModel]
+    avatar_medium: Optional[TikTokContentModel]
+    avatar_thumb: Optional[TikTokContentModel]
+    cover_url: Optional[List[TikTokContentModel]]
\ No newline at end of file
